Learn R Programming

jpinfect (version 2023.2026.02)

jpinfect-package: jpinfect: Japan Institute for Health Security Infectious Disease Data in R

Description

This package provides functions to download and post-process infectious disease data from the Japan Institute for Health Security.

Arguments

Main Functions

  • jpinfect_url_confirmed(): Display dataset URLs of Confirmed Cases based on Infectious Diseases Weekly Report (IDWR)

  • jpinfect_url_bullet(): Display Infectious Diseases Weekly Report (IDWR) URLs

  • jpinfect_get_confirmed(): Download the confirmed case datasets from the Japan Institute for Health Security (JIHS)

  • jpinfect_get_bullet(): Download the bullet reports from the Japan Institute for Health Security (JIHS)

  • jpinfect_read_confirmed(): Import one year or more years of confirmed dataset

  • jpinfect_read_bullet(): Import one week or more weeks of bullet reports

  • jpinfect_merge(): Merge multiple disease datasets into a unified data table

  • jpinfect_pivot(): Convert data from wide format to long format for easier analysis

Author

Maintainer: Tomonori Hoshi tomonori.hoshi.japan@gmail.com

Authors:

See Also