Learn R Programming

jpinfect (version 2023.2026.02)

jpinfect_url_confirmed: Display dataset URLs of Confirmed Cases based on Infectious Diseases Weekly Report (IDWR)

Description

This function displays the URL for downloading Confirmed Cases based on Infectious Diseases Weekly Report (IDWR) from the Japan Institute for Health Security (JIHS) for a specified year. See this webpage for further details: https://id-info.jihs.go.jp/

Usage

jpinfect_url_confirmed(year = 2001, type = "sex")

Value

A character string containing the URL for the specified year's data.

Arguments

year

The year for which to generate the URL. Defaults to 2001.

type

The type of data to download. Must be either "sex" or "place". Defaults to "sex".

Examples

Run this code
# \donttest{
# Check URL for weekly cases by sex and prefecture in 2010
jpinfect_url_confirmed(2010)

# Check URL for weekly cases by suspected place of infection and prefecture in 2010
jpinfect_url_confirmed(2010, type = "place")
# }

Run the code above in your browser using DataLab