| prefecture_en | R Documentation |
This vector contains the English names of all 47 prefectures in Japan, listed in geographical order, starting from Hokkaido in the north to Okinawa in the south.
prefecture_en
A character vector of length 47.
The northernmost prefecture.
Located in the Tohoku region.
Other prefectures follow in geographical order.
The southernmost prefecture.
# Access the first prefecture
prefecture_en[1] # "Hokkaido"
# Print all prefectures
print(prefecture_en)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.