Learn R Programming

jpinfect (version 2023.2026.06)

prefecture_en: English Names of Prefectures in Japan

Description

This vector contains the English names of all 47 prefectures in Japan, listed in geographical order, starting from Hokkaido in the north to Okinawa in the south.

Usage

prefecture_en

Arguments

Format

A character vector of length 47.

Hokkaido

The northernmost prefecture.

Aomori

Located in the Tohoku region.

...

Other prefectures follow in geographical order.

Okinawa

The southernmost prefecture.

Examples

Run this code
# Access the first prefecture
prefecture_en[1]  # "Hokkaido"

# Print all prefectures
print(prefecture_en)

Run the code above in your browser using DataLab